@@ -1,10 +1,13 @@
-from typing import override, Type
+from __future__ import annotations
+from typing import override, Type, TYPE_CHECKING
 
+if TYPE_CHECKING:
+    from ormlambda import Table
+    from ormlambda.components.select import ISelect
 
-from ...common.abstract_classes import AbstractSQLStatements
-from ...utils import Table
-from ...common.interfaces import IQuery, IRepositoryBase
-from ...components.select import ISelect
+from ormlambda.common.abstract_classes import AbstractSQLStatements
+
+from ormlambda.common.interfaces import IQuery, IRepositoryBase
 
 from .clauses import DeleteQuery
 from .clauses import InsertQuery
@@ -16,6 +19,7 @@ from .clauses import SelectQuery
 from .clauses import UpsertQuery
 from .clauses import UpdateQuery
 from .clauses import WhereCondition
+from .clauses import CountQuery
 
 from mysql.connector import MySQLConnection
 
@@ -60,6 +64,11 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
     def OFFSET_QUERY(self) -> Type[IQuery]:
         return OffsetQuery
 
+    @property
+    @override
+    def COUNT(self) -> int:
+        return CountQuery
+
     @property
     @override
     def JOIN_QUERY(self) -> Type[IQuery]:
